@@ -1,12 +1,13 @@
 package Catmandu::Store::CHI::Bag;
 
 use Moo;
-use Data::UUID;
-use Data::Dumper;
+use CHI;
+use Catmandu::IdGenerator::UUID;
 
 with 'Catmandu::Bag';
 
 has 'chi'    => (is => 'ro' , lazy => 1 , builder => 1);
+has 'idgen'  => (is => 'ro' , lazy => 1 , builder => 1);
 
 sub _build_chi {
     my ($self) = @_;
@@ -16,6 +17,10 @@ sub _build_chi {
     CHI->new(namespace => $name , driver => $driver, %$opts);
 }
 
+sub _build_idgen {
+    Catmandu::IdGenerator::UUID->new;
+}
+
 sub generator {
     my $self = shift;
     my $keys = [ $self->chi->get_keys ];
@@ -35,7 +40,7 @@ sub get {
 
 sub add {
     my ($self,$data) = @_;
-    $data->{_id} //= gen_id();
+    $data->{_id} //= $self->idgen->generate;
     my $id = $data->{_id};
     $self->chi->set($id,$data);
     return $data;
@@ -55,4 +60,4 @@ sub gen_id {
     Data::UUID->new->create_str();
 }
 
-1;
\ No newline at end of file
+1;
